<?php
/**
 * $Horde: trean/add.php,v 1.33 2006/01/01 21:12:00 jan Exp $
 *
 * Copyright 2002-2006 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information (BSD). If you did not
 * receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('TREAN_BASE', dirname(__FILE__));
require_once TREAN_BASE . '/lib/base.php';

/* Deal with any action task. */
$actionID = Util::getFormData('actionID');
switch ($actionID) {
case 'add_bookmark':
    /* Check permissions. */
    if (Trean::hasPermission('max_bookmarks') !== true &&
        Trean::hasPermission('max_bookmarks') <= $trean_shares->countBookmarks()) {
        $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d bookmarks."), Trean::hasPermission('max_bookmarks')), ENT_COMPAT, NLS::getCharset());
        if (!empty($conf['hooks']['permsdenied'])) {
            $message = Horde::callHook('_perms_hook_denied', array('trean:max_bookmarks'), 'horde', $message);
        }
        $notification->push($message, 'horde.error', array('content.raw'));
        header('Location: ' . Horde::applicationUrl('browse.php', true));
        exit;
    }

    $category_id = Util::getFormData('category_id', DATATREE_ROOT);
    $new_category = Util::getFormData('newCategory');

    /* Create a new category if requested */
    if ($new_category) {
        $properties = array();
        $properties['name'] = $category_id;

        $parent_id = $trean_shares->getId(Auth::getAuth());
        $parent = &$trean_shares->getCategory($parent_id);
        $result = $parent->addCategory($properties);

        if (is_a($result, 'PEAR_Error')) {
            $notification->push(sprintf(_("There was an error adding the category: %s"), $result->getMessage()), 'horde.error');
        } else {
            $category_id = $result;
        }
    }

    /* Create a new Bookmark. */
    $properties = array();
    $properties['title'] = Util::getFormData('title');
    $properties['description'] = Util::getFormData('description');
    $properties['url'] = Util::getFormData('url');

    if ($category_id == DATATREE_ROOT) {
        $bookmark = &$trean_shares->newBookmark(md5(uniqid(mt_rand())), $properties);
        $result = $trean_shares->addBookmark($bookmark);
    } else {
        $category = &$trean_shares->getCategory($category_id);
        $result = $category->addBookmark($properties);
    }

    if (is_a($result, 'PEAR_Error')) {
        $notification->push(sprintf(_("There was an error adding the bookmark: %s"), $result->getMessage()), 'horde.error');
    } else {
        if (Util::getFormData('popup')) {
            Util::closeWindowJS();
        } else {
            header('Location: ' . Horde::applicationUrl(Util::addParameter('browse.php', 'category_id', $category_id), true));
        }
        exit;
    }
    break;

case 'add_category':
    $parent_id = Util::getFormData('category_id', DATATREE_ROOT);
    if ($parent_id == DATATREE_ROOT) {
        $parent_id = $trean_shares->getId(Auth::getAuth());
    }

    /* Check permissions. */
    if (Trean::hasPermission('max_categories') !== true &&
        Trean::hasPermission('max_categories') <= Trean::countCategories()) {
        $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d categories."), Trean::hasPermission('max_categories')), ENT_COMPAT, NLS::getCharset());
        if (!empty($conf['hooks']['permsdenied'])) {
            $message = Horde::callHook('_perms_hook_denied', array('trean:max_categories'), 'horde', $message);
        }
        $notification->push($message, 'horde.error', array('content.raw'));
        header('Location: ' . Horde::applicationUrl(Util::addParameter('browse.php', 'category_id', $parent_id), true));
        exit;
    }

    $properties = array();
    $properties['name'] = Util::getFormData('name');

    $parent = &$trean_shares->getCategory($parent_id);
    $result = $parent->addCategory($properties);

    if (is_a($result, 'PEAR_Error')) {
        $notification->push(sprintf(_("There was an error adding the category: %s"), $result->getMessage()), 'horde.error');
    } else {
        header('Location: ' . Horde::applicationUrl(Util::addParameter('browse.php', 'category_id', $result), true));
        exit;
    }
    break;
}

if (Util::getFormData('popup')) {
    $notification->push('window.focus();', 'javascript');
}
$title = _("Add Bookmark");
require TREAN_TEMPLATES . '/common-header.inc';
if (!Util::getFormData('popup')) {
    require TREAN_TEMPLATES . '/menu.inc';
}
require TREAN_TEMPLATES . '/add/add.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
