<?php
/**
 * $Horde: trean/browse.php,v 1.52 2006/01/01 21:12:00 jan Exp $
 *
 * Copyright 2002-2006 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('TREAN_BASE', dirname(__FILE__));
require_once TREAN_BASE . '/lib/base.php';

/* The URL that the category tree and categories list will be linking to. */
$base_url = 'browse.php';

/* Get bookmarks to display. */
$category_id = Util::getFormData('category_id', $trean_shares->getId(Auth::getAuth()));
$category = &$trean_shares->getCategory($category_id);
if ($category_id != DATATREE_ROOT) {
    $parent = $trean_shares->getCategory($trean_shares->getParent($category->getName()));
}

/* Make sure user has permission to view this category. */
if (!$category->hasPermission(Auth::getAuth(), PERMS_READ)) {
    $notification->push(_("You do not have permission to view this category."), 'horde.error');
    header('Location: ' . Horde::applicationUrl('browse.php', true));
    exit;
}

/* Get category contents. */
if ($prefs->getValue('bookmark_template') == 'tree') {
    require_once 'Horde/Tree.php';
    $categories = Trean::listCategories();

    /* Set up the tree */
    $params = array('icondir' => $registry->getImageDir('horde') . '/tree',
                    'icon' => 'folder.png',
                    'iconopen' => 'folderopen.png');

    $tree = &Horde_Tree::factory('category_tree', 'html');
    $tree->setOption(array('class' => 'item', 'alternate' => true));

    foreach ($categories as $node_id => $node_val) {
        $parent_id = $trean_shares->getName($trean_shares->getParent($node_val));
        $indent = substr_count($node_id, ':');
        $label = $node_val->get('name');

        /* The clickable url for each node. */
        $params['url'] = Util::addParameter(Horde::applicationUrl('browse.php'), 'ht_toggle_category_tree', $node_id);

        if ($parent_id == DATATREE_ROOT) {
            $parent_id = null;
        }

        /* Add the node and add the node params */
        $tree->addNode($node_id, $parent_id, $label,
                       $indent, $category_id == $node_val->getId(), $params);
    }

    $bookmarks = Trean::listAllBookmarks();
    $params = array();
    foreach ($bookmarks as $id => $name) {
        $bookmark = &$trean_shares->getBookmark($id);
        $parent_id = $trean_shares->getName($trean_shares->getParent($bookmark));
        $indent = substr_count($name, ':');
        $label = $bookmark->get('title');

        /* load favicon */
        $icon = Trean::getFavicon($bookmark);
        $params['icon'] = basename($icon);
        $params['icondir'] = dirname($icon);

        /* Bookmark link url */
        $params['url'] = Util::addParameter(Horde::applicationUrl('redirect.php'), 'bookmark_id', $bookmark->getId());
        $params['target'] = $prefs->getValue('show_in_new_window') ? '_blank' : null;

        $tree->addNode($id, $parent_id, $label,
                       $indent, false, $params);
    }

    $template = 'tree.inc';
} else {
    $bookmarks = $category->listBookmarks();
    $categories = Trean::listCategories(PERMS_SHOW, null, $category->getName(), false);
    $template = 'bookmarks.inc';
}

$title = _("Browse");
Horde::addScriptFile('popup.js', 'horde', true);
if (count($categories)) {
    Horde::addScriptFile('stripe.js', 'horde', true);
}
require TREAN_TEMPLATES . '/common-header.inc';
require TREAN_TEMPLATES . '/menu.inc';
require TREAN_TEMPLATES . '/browse/javascript.inc';
require TREAN_TEMPLATES . '/browse/' . $template;
require $registry->get('templates', 'horde') . '/common-footer.inc';
