<?php
/**
 * $Horde: trean/data.php,v 1.43 2006/02/01 05:30:07 ben Exp $
 *
 * Copyright 2002-2006 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information (BSD). If you did not
 * receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @package Trean
 */

function export($category, $depth, $recursive = true)
{
    $name = $category->get('name');
    if (empty($name)) {
        $name = _("Bookmarks");
    }

    $output = '';
    if ($category->getId() != DATATREE_ROOT) {
        $output .= sprintf('%s<DT><H3 FOLDED ADD_DATE="%s">%s</H3>' . "\n" . '%1$s<DL><p>' . "\n",
                           str_repeat(' ', $depth * 4), time(), $name);
    }

    $bookmarks = $category->listBookmarks();
    foreach ($bookmarks as $bookmark) {
        $output .= sprintf('%s<DT><A HREF="%s" ADD_DATE="%s" LAST_VISIT="0" LAST_MODIFIED="0">%s</A>' . "\n",
                           str_repeat(' ', ($depth + 1) * 4),
                           $bookmark->get('url'),
                           time(),
                           $bookmark->get('title'));
    }

    if ($recursive) {
        $categories = Trean::listCategories(PERMS_SHOW, null,
                                            $category->getName(), false);
        foreach ($categories as $subcategory) {
            $output .= export($subcategory, $depth + 1);
        }
    }

    return $output . str_repeat(' ', $depth * 4) . '</DL><p>'  . "\n";
}

@define('TREAN_BASE', dirname(__FILE__));
require_once TREAN_BASE . '/lib/base.php';

$categories_exceeded = Trean::hasPermission('max_categories') !== true &&
Trean::hasPermission('max_categories') <= Trean::countCategories();
if ($categories_exceeded) {
    $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d categories."), Trean::hasPermission('max_categories')), ENT_COMPAT, NLS::getCharset());
    if (!empty($conf['hooks']['permsdenied'])) {
        $message = Horde::callHook('_perms_hook_denied', array('trean:max_categories'), 'horde', $message);
    }
    $notification->push($message, 'horde.warning', array('content.raw'));
}
$bookmarks_exceeded = Trean::hasPermission('max_bookmarks') !== true &&
Trean::hasPermission('max_bookmarks') <= $trean_shares->countBookmarks();
if ($bookmarks_exceeded) {
    $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d bookmarks."), Trean::hasPermission('max_bookmarks')), ENT_COMPAT, NLS::getCharset());
    if (!empty($conf['hooks']['permsdenied'])) {
        $message = Horde::callHook('_perms_hook_denied', array('trean:max_bookmarks'), 'horde', $message);
    }
    $notification->push($message, 'horde.warning', array('content.raw'));
}

switch (Util::getFormData('actionID')) {
case 'import':
    $result = Browser::wasFileUploaded('import_file');
    if (is_a($result, 'PEAR_Error')) {
        $notification->push($result->getMessage(), 'horde.error');
        break;
    }

    $target = Util::getFormData('target', DATATREE_ROOT);
    $root = &$trean_shares->getCategory($target);
    if (is_a($root, 'PEAR_Error')) {
        $notification->push($root, 'horde.error');
        break;
    }

    $lines = file($_FILES['import_file']['tmp_name']);

    $folders = 0;
    $bookmarks = 0;
    $category = &$root;
    $bookmark = null;
    $stack = array();
    $max_categories = Trean::hasPermission('max_categories');
    $num_categories = Trean::countCategories();
    $stop_categories = false;
    $max_bookmarks = Trean::hasPermission('max_bookmarks');
    $num_bookmarks = $trean_shares->countBookmarks();

    foreach ($lines as $line) {
        if (strpos($line, '<DT><H3') !== false) {
            /* Start of a category. */
            if ($stop_categories) {
                continue;
            }
            if ($max_categories !== true && $num_categories >= $max_categories) {
                $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d categories."), Trean::hasPermission('max_categories')), ENT_COMPAT, NLS::getCharset());
                if (!empty($conf['hooks']['permsdenied'])) {
                    $message = Horde::callHook('_perms_hook_denied', array('trean:max_categories'), 'horde', $message);
                }
                $notification->push($message, 'horde.error', array('content.raw'));
                $stop_categories = true;
                continue;
            }

            $stack[] = $category->getId();
            $category_id = $category->addCategory(array('name' => trim(strip_tags($line))));
            $category = &$trean_shares->getCategory($category_id);
            $bookmark = null;
            $folders++;
            $num_categories++;

        } elseif (strpos($line, '</DL>') !== false) {
            /* End of a category. */
            $category = &$trean_shares->getCategory(array_pop($stack));
            $bookmark = null;

        } elseif (preg_match("/<DT><A HREF=\"*(.*?)\".*>(.*)<\/A>/",
                             $line, $temp)) {
            /* A bookmark. */
            if ($max_bookmarks !== true && $num_bookmarks >= $max_bookmarks) {
                $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d bookmarks."), Trean::hasPermission('max_bookmarks')), ENT_COMPAT, NLS::getCharset());
                if (!empty($conf['hooks']['permsdenied'])) {
                    $message = Horde::callHook('_perms_hook_denied', array('trean:max_bookmarks'), 'horde', $message);
                }
                $notification->push($message, 'horde.error', array('content.raw'));
                $stop_bookmarks = true;
                break;
            }
            $properties = array();
            $properties['url'] = trim($temp[1]);
            $properties['title'] = trim($temp[2]);
            $properties['description'] = '';
            $bookmark_id = $category->addBookmark($properties);
            $bookmark = &$trean_shares->getBookmark($bookmark_id);
            $bookmarks++;
            $num_bookmarks++;

        } elseif (strpos($line, '<DD>') !== false) {
            if (!is_null($bookmark)) {
                $bookmark->set('description', trim(strip_tags($line)), true);
                $bookmark = null;
            }
        }
    }

    $notification->push(sprintf(_("%d Folders and %d Bookmarks imported."), $folders, $bookmarks), 'horde.success');

    $url = Util::addParameter('browse.php', 'category_id', $root->getId());
    header('Location: ' . Horde::applicationUrl($url, true));
    exit;

case 'export':
    $category_id = Util::getFormData('export_category');
    $recursive = Util::getFormData('export_recursive');
    $output = <<<EOH
<!DOCTYPE NETSCAPE-Bookmark-file-1>
<!--This is an automatically generated file.
It will be read and overwritten.
Do Not Edit! -->
<Title>Bookmarks</Title>
<H1>Bookmarks</H1>
<DL><p>

EOH;
    $category = $trean_shares->getCategory($category_id);
    $output .= export($category, 1, $recursive) . '</DL><p>' . "\n";

    $browser->downloadHeaders('bookmarks.html', 'text/html', false,
                              strlen($output));
    echo $output;
    exit;
}

$title = _("Import Bookmarks");
require TREAN_TEMPLATES . '/common-header.inc';
require TREAN_TEMPLATES . '/menu.inc';
if (!$categories_exceeded || !$bookmarks_exceeded) {
    require TREAN_TEMPLATES . '/data/import.inc';
}
require TREAN_TEMPLATES . '/data/export.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
