<?php

$block_name = _("Bookmarks");

/**
 * Implementation of Horde_Block api to show bookmarks.
 *
 * $Horde: trean/lib/Block/bookmarks.php,v 1.28 2006/01/02 18:19:17 jan Exp $
 *
 * Copyright 2004-2006 Joel Vandal <jvandal@infoteck.qc.ca>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Joel Vandal <jvandal@infoteck.qc.ca>
 * @since   Trean 1.0
 * @package Horde_Block
 */
class Horde_Block_Trean_bookmarks extends Horde_Block {

    var $_app = 'trean';
    var $_category = null;

    function _params()
    {
        require_once dirname(__FILE__) . '/../base.php';

        /* Get categories to display. */
        $categories = &Trean::listCategories(PERMS_READ);
        $root = DATATREE_ROOT;
        foreach ($categories as $key => $category) {
            if ($key == DATATREE_ROOT) {
                continue;
            }
            if ($root == DATATREE_ROOT) {
                $root = $category->getId();
            }
            $values[$category->getId()] = $category->get('name');
        }

        return array('category' => array('name' => _("Category"),
                                         'type' => 'enum',
                                         'default' => $root,
                                         'values' => $values),
                     'bookmarks' => array('name' => _("Bookmarks"),
                                          'type' => 'enum',
                                          'default' => 'all',
                                          'values' => array('all' => _("All Bookmarks"),
                                                            'highest_rated' => _("Top 10 Highest Rated"),
                                                            'most_clicked' => _("Top 10 Most Clicked"))),
                     'template' => array('name' => _("Template"),
                                         'type' => 'enum',
                                         'default' => '1line',
                                         'values' => array('standard' => _("3 Line"),
                                                           '2line' => _("2 Line"),
                                                           '1line' => _("1 Line"))));
    }

    /**
     * The title to go in this block.
     *
     * @return string   The title text.
     */
    function _title()
    {
        global $registry;

        $category = &$this->_getCategory();
        if (is_a($category, 'PEAR_Error')) {
            $name = $registry->get('name');
        } else {
            $name = $category->get('name');
            if (!$name) {
                $name = _("Bookmarks");
            }
        }

        return Horde::link(Horde::url($registry->getInitialPage(), true)) .
            $name . '</a> :: <small>' .
            Horde::link(Horde::applicationUrl('add.php', true)) .
            Horde::img('add.png', _("New Bookmark")) . _("New Bookmark") .
            '</a></small>';
    }

    /**
     * The content to go in this block.
     *
     * @return string   The content
     */
    function _content()
    {
        require_once dirname(__FILE__) . '/../base.php';

        $template = TREAN_TEMPLATES . '/block/' . $this->_params['template'] . '.inc';

        $category = &$this->_getCategory();
        if (is_a($category, 'PEAR_Error')) {
            return $category;
        }

        $html = '';
        $count = 0;

        switch ($this->_params['bookmarks']) {
        case 'highest_rated':
            $bookmarks = &$GLOBALS['trean_shares']->listBookmarks($category->getName(), true, 0, 10, 'rating', 1);
            break;

        case 'most_clicked':
            $bookmarks = &$GLOBALS['trean_shares']->listBookmarks($category->getName(), true, 0, 10, 'clicks', 1);
            break;

        default:
            $bookmarks = &$category->listBookmarks();
        }
        foreach ($bookmarks as $bookmark) {
            ob_start();
            require $template;
            $html .= '<div class="item' . ($count++ % 2) . '">' . ob_get_contents() . '</div>';
            ob_end_clean();
        }

        if ($count == 0) {
            return '<div><em>' . _("No bookmarks to display") . '</em></div>';
        }

        return $html;
    }

    function &_getCategory()
    {
        require_once dirname(__FILE__) . '/../base.php';

        if ($this->_category == null) {
            $this->_category = &$GLOBALS['trean_shares']->getCategory($this->_params['category']);
        }

        return $this->_category;
    }

}
