#!/usr/bin/php
<?php
/**
 * $Horde: trean/scripts/upgrades/2005-01-04_fix_upgrades.php,v 1.6 2006/04/18 15:39:38 jan Exp $
 *
 * This is a script attempts to fix botched upgrades from previous upgrade
 * scripts. There is no need to run it if you have a working trean
 * installation.
 */

// No auth.
@define('AUTH_HANDLER', true);

// Find the base file path of Horde.
@define('TREAN_BASE', dirname(__FILE__) . '/../..');

// Do CLI checks and environment setup first.
require_once TREAN_BASE . '/lib/base.php';
require_once 'Horde/CLI.php';

if (!isset($trean_bookmarks)) {
    $trean_bookmarks = &$trean_shares;
}

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();

require_once 'Horde/DataTree.php';

/**
 * Conversion helper class
 */
class Bookmark {
    var $_properties = array();
    function Bookmark($properties)
    {
        $this->_properties = $properties;
    }
}

class DataTreeObject_Conversion extends DataTreeObject {
    function _fromAttributes($attributes)
    {
        $bookmarks = array();

        foreach ($attributes as $attr) {
            if (substr($attr['name'], 0, 9) == 'bookmarks') {
                $bookmarks[substr($attr['name'], 10)][$attr['key']] = $attr['value'];
            } else {
                $this->data[$attr['name']] = $attr['value'];
            }
        }

        foreach ($bookmarks as $name => $properties) {
            $this->data['bookmarks'][$name] = &new Bookmark($properties);
        }
    }
}

/**
 * Convert a 1st generation category (bookmarks stored in datatree_data field)
 */
function convert_1st_generation($id)
{
    echo "  1st generation category\n";

    global $trean_bookmarks;

    // extract data
    $object = $trean_bookmarks->_datatree->getObjectById($id, 'DataTreeObject');
    $data = $object->getData();

    echo '    ' . $object->getName() . "\n";

    // fix category values
    $name = substr($object->getName(), strrpos($object->getName(), ':'));
    if (substr($name, 0, 1) == ':') {
        $name = substr($name, 1);
    }
    $category = $trean_bookmarks->getCategory($id);
    $category->set('name', $name, true);
    $category->set('type', 'category', true);

    if (!empty($data['bookmarks'])) {
        foreach ($data['bookmarks'] as $name => $bookmark) {
            echo '      ' . $bookmark->_properties['name'] . "\n";
            $properties['title'] = $bookmark->_properties['name'];
            $properties['url']= $bookmark->_properties['url'];
            $properties['description'] = $bookmark->_properties['description'];
            $category->addBookmark($properties);
        }
    }

    // check sub-categories
    $children = $trean_bookmarks->_datatree->getById(DATATREE_FORMAT_FLAT, $id, true, $id, 1);
    foreach ($children as $id => $name) {
        check($id);
    }
}

/**
 * Convert a 2nd generation category (bookmarks stored in attributes)
 */
function convert_2nd_generation($id)
{
    echo "  2nd generation category\n";

    global $trean_bookmarks;

    // extract data
    $object = $trean_bookmarks->_datatree->getObjectById($id, 'DataTreeObject_Conversion');
    $data = $object->getData();

    echo '    ' . $object->getName() . "\n";

    // clean up old category
    $name = substr($object->getName(), strrpos($object->getName(), ':'));
    if (substr($name, 0, 1) == ':') {
        $name = substr($name, 1);
    }
    $category = $trean_bookmarks->getCategory($id);
    $category->set('name', $name, true);
    $category->set('type', 'category', true);

    if (!empty($data['bookmarks'])) {
        foreach ($data['bookmarks'] as $name => $bookmark) {
            echo '      ' . $bookmark->_properties['name'] . "\n";
            $properties['title'] = $bookmark->_properties['name'];
            $properties['url']= $bookmark->_properties['url'];
            $properties['description'] = $bookmark->_properties['description'];
            $category->addBookmark($properties);
        }
    }

    // check sub-categories
    $children = $trean_bookmarks->_datatree->getById(DATATREE_FORMAT_FLAT, $id, true, $id, 1);
    foreach ($children as $id => $name) {
        check($id);
    }
}

/**
 * Check 3rd generation category (current format) for child categories
 * that need to be updated.
 */
function check_3rd_generation($id)
{
    global $trean_bookmarks;
    $children = $trean_bookmarks->_datatree->getById(DATATREE_FORMAT_FLAT, $id, true, $id, 1);
    foreach ($children as $id => $name) {
        check($id);
    }
}

/**
 * Get children of the given root and check the format.  Calls a
 * conversion function if format is not current.
 */
function check($root)
{
    global $trean_bookmarks;

    // Get objects in this group and loop through them.
    $objects = $trean_bookmarks->_datatree->getById(DATATREE_FORMAT_FLAT, $root, true, $root, 1);
    foreach ($objects as $id => $name) {
        // Do nothing for the root.
        if ($id == $root) {
            continue;
        }

        $object = $trean_bookmarks->_datatree->getObjectById($id, 'DataTreeObject');
        if ($trean_bookmarks->_datatree->getData($id)) {
            convert_1st_generation($id);
        } else {
            $object = $trean_bookmarks->_datatree->getObjectById($id, 'DataTreeObject_Conversion');
            if (!$object->get('type')) {
                convert_2nd_generation($id);
            } else {
                check_3rd_generation($id);
            }
        }

    }
}

$datatree = &DataTree::factory('sql');
$db = &$datatree->_db;

$driver = $conf['datatree']['driver'];
$query = 'SELECT DISTINCT group_uid FROM horde_datatree WHERE group_uid LIKE \'trean.bookmarks.%\'';
$groups = $db->getAll($query);
foreach ($groups as $row) {
    echo 'Converting ' . $row[0] . "\n";

    // Set the datatree group_uid.
    $trean_bookmarks->_datatree = &Datatree::singleton(
        $driver,
        array_merge(Horde::getDriverConfig('datatree', $driver), array('group' => $row[0]))
    );

    check(DATATREE_ROOT);
}
