#!/usr/bin/php
<?php
/**
 * $Horde: trean/scripts/upgrades/2005-03-15_move_to_horde_share.php,v 1.5 2006/04/18 15:39:39 jan Exp $
 *
 * This script upgrades any stored bookmarks & categories to Horde_Share
 * objects.  Make sure you back up your database before running this.
 */

// No auth.
@define('AUTH_HANDLER', true);

// Find the base file path of Horde.
@define('TREAN_BASE', dirname(__FILE__) . '/../..');
@define('HORDE_BASE', dirname(__FILE__) . '/../../..');

// Load the Horde Framework core, and set up inclusion paths.
require_once HORDE_BASE . '/lib/core.php';

// Do CLI checks and environment setup first.
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();

require_once TREAN_BASE . '/lib/base.php';
require_once 'Horde/Identity.php';
require_once 'Horde/DataTree.php';

// Helper class
class DataTreeObject_Helper extends DataTreeObject {

    function DataTreeObject_Helper($name)
    {
        parent::DataTreeObject($name);
        $this->data['type'] = 'category';
    }

    function _toAttributes()
    {
        foreach ($this->data as $key => $value) {
            $attributes[] = array('name' => $key,
                                  'key' => '',
                                  'value' => $value);
            if ($key == 'owner') {
                $attributes[] = array('name' => 'perm_users',
                                      'key' => $value,
                                      'value' => '30');
            }
        }
        return $attributes;
    }

    function _fromAttributes($attributes)
    {
        foreach ($attributes as $attribute) {
            $this->data[$attribute['name']] = $attribute['value'];
        }
    }
}

// Helper function
function &listBookmarks()
{
    global $datatree;
    $criteria = array('AND' => array(
                          array('field' => 'name',
                                'op' => '=',
                                'test' => 'type'),
                          array('field' => 'value',
                                'op' => '=',
                                'test' => 'bookmark')));
    $ids = &$datatree->getByAttributes($criteria, DATATREE_ROOT, false);
    return $datatree->getObjects(array_keys($ids), 'DataTreeObject_Bookmark');
}

// Helper function
function &listCategories()
{
    global $datatree;
    $criteria = array('AND' => array(
                          array('field' => 'name',
                                'op' => '=',
                                'test' => 'type'),
                          array('field' => 'value',
                                'op' => '=',
                                'test' => 'category')));

    $ids = &$datatree->getByAttributes($criteria);
    return $datatree->getObjects(array_keys($ids), 'DataTreeObject_Helper');
}

$datatree = &Datatree::factory('sql');
$db = &$datatree->_db;

$query = 'SELECT DISTINCT group_uid from horde_datatree WHERE group_uid LIKE \'trean.bookmarks.%\'';
$groups = $db->getAll($query);

foreach ($groups as $row) {
    echo 'Converting ' . $row[0] . "\n";

    // set the datatree group_uid
    $datatree = &Datatree::singleton('sql',
        array_merge(Horde::getDriverConfig('datatree', 'sql'), array('group' => $row[0]))
    );

    $categories = &listCategories();
    $bookmarks = &listBookmarks();

    // Make sure "My Bookmarks" category exists
    $owner = substr($row[0], 16);
    if (!$datatree->exists($owner)) {
        $identity = &Identity::singleton('none', $owner);
        $name = $identity->getValue('fullname');
        $root = &new DataTreeObject_Helper($owner);
        $root->set('owner', $owner);
        $root->set('name', sprintf(_("%s's Bookmarks"), $name ? $name : $owner));
        $datatree->updateData($root);
        $datatree->add($root);

        $query = 'UPDATE horde_datatree SET user_uid = ' . $db->quote($owner) . ' where datatree_name = ' . $db->quote($owner) . ' and group_uid = ' . $db->quote($row[0]);
        $db->query($query);
    }

    foreach ($categories as $category_id => $category) {
        $category->set('owner', $owner);
        $datatree->updateData($category);

        if ($datatree->getParent($category) == DATATREE_ROOT) {
            echo "  " . $category->get('name') . "...";
            $datatree->move($category, $owner);
            echo "done\n";
        }
    }

    foreach ($bookmarks as $bookmark_id => $bookmark) {
        $datatree->move($bookmark, $owner);
    }
}

$query = 'UPDATE horde_datatree SET group_uid = \'horde.shares.trean\' where group_uid LIKE \'trean.bookmarks.%\'';
$db->query($query);
