#!/usr/bin/php
<?php
/**
 * $Horde: trean/scripts/upgrades/2005-03-16_fix_parents.php,v 1.4 2006/04/18 15:39:39 jan Exp $
 *
 * The 2005-03-15_move_to_horde_share.php upgrade script failed to
 * properly update the parent paths in the datatree backend, resulting
 * in a list of empty categories.  This script regenerates all of
 * the parent paths to restore the category list.
 *
 * This script should be run *AFTER* running
 * 2005-03-15_move_to_horde_share.php
 *
 * Be sure to back up your database before running any upgrade scripts
 */

// No auth.
@define('AUTH_HANDLER', true);

// Find the base file path of Horde.
@define('TREAN_BASE', dirname(__FILE__) . '/../..');
@define('HORDE_BASE', dirname(__FILE__) . '/../../..');

// Load the Horde Framework core, and set up inclusion paths.
require_once HORDE_BASE . '/lib/core.php';

// Do CLI checks and environment setup first.
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();

require_once TREAN_BASE . '/lib/base.php';

$db = &$trean_shares->_datatree->_db;

$query = 'SELECT DISTINCT user_uid FROM horde_datatree' .
         ' WHERE group_uid = ?';
$values = array('horde.shares.trean');
$users = $db->getAll($query, $values);
foreach ($users as $row) {
    echo 'Fixing ' . $row[0] . '...';

    $query = 'SELECT datatree_id FROM horde_datatree' .
             ' WHERE group_uid = ? AND datatree_name = ?';
    $values = array('horde.shares.trean', $row[0]);
    $root = $db->getOne($query, $values);

    $query = 'SELECT datatree_id, datatree_parents FROM horde_datatree' .
             ' WHERE group_uid = ? AND user_uid = ? AND datatree_name <> ?';
    $values = array('horde.shares.trean', $row[0], $row[0]);
    $bookmarks = $db->getAll($query, $values);
    foreach ($bookmarks as $bookmark) {
        if (!strpos($bookmark[1], $root)) {
            $query = 'UPDATE horde_datatree' .
                     ' SET datatree_parents = ?' .
                     ' WHERE datatree_id = ?';
            $values = array(':' . $root . $bookmark[1], $bookmark[0]);
            $db->query($query, $values);
        }
    }

    echo "done\n";
}
